@@ -1,15 +1,12 @@
 #include "mainwindow.h"
-#include "ui_mainwindow.h"
 #include "selectalarmtype.h"
 #include "alarmhistory.h"
 #include "settings.h"
 #include "about.h"
 #include "daemon.h"
-#include "alarm.h"
-#include "backend.h"
-#include "module_list.h"
 
 #include <QDeclarativeContext>
+#include <QDeclarativeView>
 #include <QDBusConnection>
 #include <QSettings>
 #include <QGraphicsObject>
@@ -24,23 +21,30 @@
 
 MainWindow::MainWindow(QWidget *parent) :
     QMainWindow(parent),
-    ui(new Ui::MainWindow)
+    view(new QDeclarativeView(this))
 {
-    ui->setupUi(this);
+    setWindowTitle("EvilAlarm");
     setAttribute(Qt::WA_Maemo5StackedWindow);
 
+    menuBar()->addAction(tr("Settings"), this, SLOT(showSettings()));
+    menuBar()->addAction(tr("About"), this, SLOT(showAbout()));
+    menuBar()->addAction(tr("Test Alarm"), this, SLOT(testAlarm()));
 
-    QString path;
-    const QString maemo_install_path("/opt/evilalarm/qml/main.qml");
-    if(QFile::exists(maemo_install_path)) {
-        path = maemo_install_path;
-    } else { //for QtCreator
-        path = QApplication::applicationDirPath()+"/../qml/qml/main.qml";
+    QString path("/opt/evilalarm/qml/main.qml");
+    if(!QFile::exists(path)) { //for QtCreator
+        path = QApplication::applicationDirPath() + "/../qml/qml/main.qml";
     }
 
+    //avoid flicker at start
+    setAttribute(Qt::WA_OpaquePaintEvent);
+    setAttribute(Qt::WA_NoSystemBackground);
+    view->setAttribute(Qt::WA_OpaquePaintEvent);
+    view->setAttribute(Qt::WA_NoSystemBackground);
+
     //now load UI
-    ui->view->setSource(QUrl::fromLocalFile(path));
-    QGraphicsObject *root_object = ui->view->rootObject();
+    view->setSource(QUrl::fromLocalFile(path));
+    QGraphicsObject *root_object = view->rootObject();
+
 
     //load alarm
     QSettings settings;
@@ -68,32 +72,31 @@ MainWindow::MainWindow(QWidget *parent) :
         QMaemo5InformationBox::information(this, tr("Can't write settings to /home/user/.config/EvilAlarm/EvilAlarm - Please fix its file permissions and restart EvilAlarm"));
     }
 
-    if(!QFile::permissions(KEEPVOLUME_PATH).testFlag(QFile::ReadOther)) {
-        QMaemo5InformationBox::information(this, tr("Can't access %1 - Please reinstall EvilAlarm!").arg(KEEPVOLUME_PATH));
+    const QString file_path("/opt/evilalarm/bin/keepvolume.sh");
+    if(!QFile::permissions(file_path).testFlag(QFile::ExeOther)) {
+        QMaemo5InformationBox::information(this, tr("Can't execute %1 - Please reinstall EvilAlarm!").arg(file_path));
     }
 }
 
 MainWindow::~MainWindow()
 {
-    delete ui;
+    delete view;
 }
 
 void MainWindow::showAlarmTypeSelector()
 {
     SelectAlarmType* selectAlarmType = new SelectAlarmType(this);
     selectAlarmType->exec();
+    delete selectAlarmType;
 
-    QGraphicsObject *root_object = ui->view->rootObject();
+    QGraphicsObject *root_object = view->rootObject();
     QSettings settings;
     root_object->setProperty("ui_alarm_type", settings.value("module", "Normal").toString());
-
-    delete selectAlarmType;
 }
 
 
 void MainWindow::setEvilAlarm(int hours, int minutes)
 {
-    std::cout << "setEvilAlarm(" << hours << ", " << minutes << ")\n";
     QSettings settings;
 
     const QTime wake_at(hours, minutes);
@@ -121,7 +124,6 @@ void MainWindow::setEvilAlarm(int hours, int minutes)
 
 void MainWindow::unsetEvilAlarm()
 {
-    std::cout << "unsetEvilAlarm()\n";
     Daemon::stop();
 
     //since unsetEvilAlarm() is only called when the user deactivates a set alarm, remove the most recent alarm from history
@@ -141,7 +143,7 @@ void MainWindow::unsetEvilAlarm()
     settings.sync();
 }
 
-void MainWindow::on_actionSettings_triggered()
+void MainWindow::showSettings()
 {
     Settings *settingsWindow = new Settings(this);
     settingsWindow->setAttribute(Qt::WA_Maemo5StackedWindow);
@@ -149,12 +151,12 @@ void MainWindow::on_actionSettings_triggered()
     settingsWindow->exec();
     delete settingsWindow;
 
-    QGraphicsObject *root_object = ui->view->rootObject();
+    QGraphicsObject *root_object = view->rootObject();
     QSettings settings;
     root_object->setProperty("ui_alarm_type", settings.value("module", "Normal").toString());
 }
 
-void MainWindow::on_actionAbout_triggered()
+void MainWindow::showAbout()
 {
     static About *about = new About(this);
     about->setAttribute(Qt::WA_Maemo5StackedWindow);
@@ -162,17 +164,15 @@ void MainWindow::on_actionAbout_triggered()
     about->show();
 }
 
-void MainWindow::on_actionTest_Alarm_triggered()
+void MainWindow::testAlarm()
 {
-    Alarm* test_alarm = ModuleList::getModuleInstance(this);
-    test_alarm->exec();
-    delete test_alarm;
+    QProcess::execute(QString("evilalarm --test"));
 }
 
 void MainWindow::displayStateChanged(QString state)
 {
     const bool display_on = (state != "off");
-    QGraphicsObject *root_object = ui->view->rootObject();
+    QGraphicsObject *root_object = view->rootObject();
     root_object->setProperty("displayOn", display_on);
 }
 
@@ -185,17 +185,14 @@ void MainWindow::showAlarmHistory(int hours, int minutes)
     delete alarmHistory;
 }
 
-//set alarm in UI (onChanged handlers are triggered)
+//set alarm in UI (which in turn starts the daemon)
 void MainWindow::setUIAlarm(int hours, int minutes)
 {
-    QGraphicsObject *root_object = ui->view->rootObject();
+    QObject *root_object = view->rootObject();
+
     //disable old alarm first
     //(changing hours / minutes to something else is required to trigger the onChanged slots...)
-    root_object->setProperty("ui_alarm_active", false);
-    root_object->setProperty("ui_alarm_hours", -1);
-    root_object->setProperty("ui_alarm_minutes", -1);
+    QMetaObject::invokeMethod(root_object, "setUiAlarm", Q_ARG(int, -1), Q_ARG(int, -1), Q_ARG(bool, false));
 
-    root_object->setProperty("ui_alarm_hours", hours);
-    root_object->setProperty("ui_alarm_minutes", minutes);
-    root_object->setProperty("ui_alarm_active", true);
+    QMetaObject::invokeMethod(root_object, "setUiAlarm", Q_ARG(int, hours), Q_ARG(int, minutes), Q_ARG(bool, true));
 }
